package
Version:
v0.1.11
Opens a new window with list of versions in this module.
Published: Mar 23, 2025
License: GPL-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Debug(format string, v ...interface{})
Debug logs a debug message
func Error(format string, v ...interface{})
Error logs an error message
func Fatal(format string, v ...interface{})
Fatal logs an error message and exits
func Info(format string, v ...interface{})
Info logs an info message
SetLevel sets the logging level
const (
LevelError Level = iota
LevelInfo
LevelDebug
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.